@@ -1,4 +1,4 @@
-/* $Id: cheat_gui.cpp 22224 2011-03-07 19:18:38Z rubidium $ */
+/* $Id: cheat_gui.cpp 24900 2013-01-08 22:46:42Z planetmaker $ */
 
 /*
  * This file is part of OpenTTD.
@@ -18,16 +18,15 @@
 #include "saveload/saveload.h"
 #include "textbuf_gui.h"
 #include "window_gui.h"
-#include "newgrf.h"
 #include "string_func.h"
 #include "strings_func.h"
 #include "window_func.h"
 #include "rail_gui.h"
-#include "gui.h"
+#include "settings_gui.h"
 #include "company_gui.h"
-#include "gamelog.h"
 
-#include "table/strings.h"
+#include "widgets/cheat_widget.h"
+
 #include "table/sprites.h"
 
 
@@ -76,7 +75,7 @@ static int32 ClickChangeCompanyCheat(int32 p1, int32 p2)
  * Allow (or disallow) changing production of all industries.
  * @param p1 new value
  * @param p2 unused
- * @return New value allwing change of industry production.
+ * @return New value allowing change of industry production.
  */
 static int32 ClickSetProdCheat(int32 p1, int32 p2)
 {
@@ -85,26 +84,6 @@ static int32 ClickSetProdCheat(int32 p1, int32 p2)
 	return _cheats.setup_prod.value;
 }
 
-/**
- * Handle changing of climate.
- * @param p1 New climate.
- * @param p2 Unused.
- * @return New climate.
- */
-static int32 ClickChangeClimateCheat(int32 p1, int32 p2)
-{
-	if (p1 == -1) p1 = 3;
-	if (p1 ==  4) p1 = 0;
-	_settings_game.game_creation.landscape = p1;
-
-	GamelogStartAction(GLAT_CHEAT);
-	GamelogTestMode();
-	ReloadNewGRFData();
-	GamelogStopAction();
-
-	return _settings_game.game_creation.landscape;
-}
-
 extern void EnginesMonthlyLoop();
 
 /**
@@ -138,7 +117,6 @@ enum CheatNumbers {
 	CHT_CROSSINGTUNNELS, ///< Allow tunnels to cross each other.
 	CHT_NO_JETCRASH,     ///< Disable jet-airplane crashes.
 	CHT_SETUP_PROD,      ///< Allow manually editing of industry production.
-	CHT_SWITCH_CLIMATE,  ///< Switch climate.
 	CHT_CHANGE_DATE,     ///< Do time traveling.
 
 	CHT_NUM_CHEATS,      ///< Number of cheats.
@@ -171,17 +149,11 @@ static const CheatEntry _cheats_ui[] = {
 	{SLE_BOOL,  STR_CHEAT_CROSSINGTUNNELS, &_cheats.crossing_tunnels.value,         &_cheats.crossing_tunnels.been_used, NULL                     },
 	{SLE_BOOL,  STR_CHEAT_NO_JETCRASH,     &_cheats.no_jetcrash.value,              &_cheats.no_jetcrash.been_used,      NULL                     },
 	{SLE_BOOL,  STR_CHEAT_SETUP_PROD,      &_cheats.setup_prod.value,               &_cheats.setup_prod.been_used,       &ClickSetProdCheat       },
-	{SLE_UINT8, STR_CHEAT_SWITCH_CLIMATE,  &_settings_game.game_creation.landscape, &_cheats.switch_climate.been_used,   &ClickChangeClimateCheat },
 	{SLE_INT32, STR_CHEAT_CHANGE_DATE,     &_cur_year,                              &_cheats.change_date.been_used,      &ClickChangeDateCheat    },
 };
 
 assert_compile(CHT_NUM_CHEATS == lengthof(_cheats_ui));
 
-/** Names of the cheat window widgets. */
-enum CheatWidgets {
-	CW_PANEL,
-};
-
 /** Widget definitions of the cheat GUI. */
 static const NWidgetPart _nested_cheat_widgets[] = {
 	NWidget(NWID_HORIZONTAL),
@@ -190,7 +162,7 @@ static const NWidgetPart _nested_cheat_widgets[] = {
 		NWidget(WWT_SHADEBOX, COLOUR_GREY),
 		NWidget(WWT_STICKYBOX, COLOUR_GREY),
 	EndContainer(),
-	NWidget(WWT_PANEL, COLOUR_GREY, CW_PANEL), SetDataTip(0x0, STR_CHEATS_TOOLTIP), EndContainer(),
+	NWidget(WWT_PANEL, COLOUR_GREY, WID_C_PANEL), SetDataTip(0x0, STR_CHEATS_TOOLTIP), EndContainer(),
 };
 
 /** GUI for the cheats. */
@@ -205,16 +177,16 @@ struct CheatWindow : Window {
 
 	virtual void DrawWidget(const Rect &r, int widget) const
 	{
-		if (widget != CW_PANEL) return;
+		if (widget != WID_C_PANEL) return;
 
 		int y = r.top + WD_FRAMERECT_TOP + this->header_height;
 		DrawStringMultiLine(r.left + WD_FRAMERECT_LEFT, r.right - WD_FRAMERECT_LEFT, r.top + WD_FRAMERECT_TOP, y, STR_CHEATS_WARNING, TC_FROMSTRING, SA_CENTER);
 
 		bool rtl = _current_text_dir == TD_RTL;
 		uint box_left    = rtl ? r.right - 12 : r.left + 5;
-		uint button_left = rtl ? r.right - 40 : r.left + 20;
-		uint text_left   = r.left + (rtl ? WD_FRAMERECT_LEFT: 50);
-		uint text_right  = r.right - (rtl ? 50 : WD_FRAMERECT_RIGHT);
+		uint button_left = rtl ? r.right - 20 - SETTING_BUTTON_WIDTH : r.left + 20;
+		uint text_left   = r.left + (rtl ? WD_FRAMERECT_LEFT : 30 + SETTING_BUTTON_WIDTH);
+		uint text_right  = r.right - (rtl ? 30 + SETTING_BUTTON_WIDTH : WD_FRAMERECT_RIGHT);
 
 		for (int i = 0; i != lengthof(_cheats_ui); i++) {
 			const CheatEntry *ce = &_cheats_ui[i];
@@ -225,7 +197,7 @@ struct CheatWindow : Window {
 				case SLE_BOOL: {
 					bool on = (*(bool*)ce->variable);
 
-					DrawFrameRect(button_left, y + 1, button_left + 20 - 1, y + FONT_HEIGHT_NORMAL - 1, on ? COLOUR_GREEN : COLOUR_RED, on ? FR_LOWERED : FR_NONE);
+					DrawBoolButton(button_left, y, on, true);
 					SetDParam(0, on ? STR_CONFIG_SETTING_ON : STR_CONFIG_SETTING_OFF);
 					break;
 				}
@@ -250,10 +222,6 @@ struct CheatWindow : Window {
 							break;
 						}
 
-						/* Set correct string for switch climate cheat */
-						case STR_CHEAT_SWITCH_CLIMATE: val += STR_CHEAT_SWITCH_CLIMATE_TEMPERATE_LANDSCAPE;
-							/* FALL THROUGH */
-
 						default: SetDParam(0, val);
 					}
 					break;
@@ -268,7 +236,7 @@ struct CheatWindow : Window {
 
 	virtual void UpdateWidgetSize(int widget, Dimension *size, const Dimension &padding, Dimension *fill, Dimension *resize)
 	{
-		if (widget != CW_PANEL) return;
+		if (widget != WID_C_PANEL) return;
 
 		uint width = 0;
 		for (int i = 0; i != lengthof(_cheats_ui); i++) {
@@ -291,18 +259,10 @@ struct CheatWindow : Window {
 
 						/* Draw coloured flag for change company cheat */
 						case STR_CHEAT_CHANGE_COMPANY:
-							SetDParam(0, 15);
+							SetDParamMaxValue(0, MAX_COMPANIES);
 							width = max(width, GetStringBoundingBox(ce->str).width + 10 + 10);
 							break;
 
-						/* Set correct string for switch climate cheat */
-						case STR_CHEAT_SWITCH_CLIMATE:
-							for (StringID i = STR_CHEAT_SWITCH_CLIMATE_TEMPERATE_LANDSCAPE; i <= STR_CHEAT_SWITCH_CLIMATE_TOYLAND_LANDSCAPE; i++) {
-								SetDParam(0, i);
-								width = max(width, GetStringBoundingBox(ce->str).width);
-							}
-							break;
-
 						default:
 							SetDParam(0, INT64_MAX);
 							width = max(width, GetStringBoundingBox(ce->str).width);
@@ -319,7 +279,7 @@ struct CheatWindow : Window {
 
 	virtual void OnClick(Point pt, int widget, int click_count)
 	{
-		const NWidgetBase *wid = this->GetWidget<NWidgetBase>(CW_PANEL);
+		const NWidgetBase *wid = this->GetWidget<NWidgetBase>(WID_C_PANEL);
 		uint btn = (pt.y - wid->pos_y - WD_FRAMERECT_TOP - this->header_height) / (FONT_HEIGHT_NORMAL + WD_PAR_VSEP_NORMAL);
 		uint x = pt.x - wid->pos_x;
 		bool rtl = _current_text_dir == TD_RTL;
@@ -331,15 +291,15 @@ struct CheatWindow : Window {
 		int value = (int32)ReadValue(ce->variable, ce->type);
 		int oldvalue = value;
 
-		if (btn == CHT_CHANGE_DATE && x >= 40) {
+		if (btn == CHT_CHANGE_DATE && x >= 20 + SETTING_BUTTON_WIDTH) {
 			/* Click at the date text directly. */
 			SetDParam(0, value);
-			ShowQueryString(STR_JUST_INT, STR_CHEAT_CHANGE_DATE_QUERY_CAPT, 8, 100, this, CS_NUMERAL, QSF_ACCEPT_UNCHANGED);
+			ShowQueryString(STR_JUST_INT, STR_CHEAT_CHANGE_DATE_QUERY_CAPT, 8, this, CS_NUMERAL, QSF_ACCEPT_UNCHANGED);
 			return;
 		}
 
 		/* Not clicking a button? */
-		if (!IsInsideMM(x, 20, 40)) return;
+		if (!IsInsideMM(x, 20, 20 + SETTING_BUTTON_WIDTH)) return;
 
 		*ce->been_used = true;
 
@@ -351,16 +311,16 @@ struct CheatWindow : Window {
 
 			default:
 				/* Take whatever the function returns */
-				value = ce->proc(value + ((x >= 30) ? 1 : -1), (x >= 30) ? 1 : -1);
+				value = ce->proc(value + ((x >= 20 + SETTING_BUTTON_WIDTH / 2) ? 1 : -1), (x >= 20 + SETTING_BUTTON_WIDTH / 2) ? 1 : -1);
 
 				/* The first cheat (money), doesn't return a different value. */
-				if (value != oldvalue || btn == CHT_MONEY) this->clicked = btn * 2 + 1 + ((x >= 30) != rtl ? 1 : 0);
+				if (value != oldvalue || btn == CHT_MONEY) this->clicked = btn * 2 + 1 + ((x >= 20 + SETTING_BUTTON_WIDTH / 2) != rtl ? 1 : 0);
 				break;
 		}
 
 		if (value != oldvalue) WriteValue(ce->variable, ce->type, (int64)value);
 
-		this->flags4 |= WF_TIMEOUT_BEGIN;
+		this->SetTimeout();
 
 		this->SetDirty();
 	}
@@ -391,7 +351,7 @@ struct CheatWindow : Window {
 static const WindowDesc _cheats_desc(
 	WDP_AUTO, 0, 0,
 	WC_CHEATS, WC_NONE,
-	WDF_UNCLICK_BUTTONS,
+	0,
 	_nested_cheat_widgets, lengthof(_nested_cheat_widgets)
 );
 
