@@ -1,4 +1,4 @@
-/* $Id: saveload.h 22886 2011-09-03 18:56:34Z frosch $ */
+/* $Id: saveload.h 23603 2011-12-19 20:50:44Z truebrain $ */
 
 /*
  * This file is part of OpenTTD.
@@ -40,7 +40,7 @@ enum SavegameType {
 	SGT_TTDP2,  ///< TTDP savegame in new format (data at SE border)
 	SGT_OTTD,   ///< OTTD savegame
 	SGT_TTO,    ///< TTO savegame
-	SGT_INVALID = 0xFF ///< broken savegame (used internally)
+	SGT_INVALID = 0xFF, ///< broken savegame (used internally)
 };
 
 void GenerateDefaultSaveName(char *buf, const char *last);
@@ -82,6 +82,7 @@ enum SLRefType {
 	REF_ENGINE_RENEWS = 6, ///< Load/save a reference to an engine renewal (autoreplace).
 	REF_CARGO_PACKET  = 7, ///< Load/save a reference to a cargo packet.
 	REF_ORDERLIST     = 8, ///< Load/save a reference to an orderlist.
+	REF_STORAGE       = 9, ///< Load/save a reference to a persistent storage.
 };
 
 /** Highest possible savegame version. */
@@ -170,10 +171,12 @@ enum VarTypes {
 
 	/* 8 bits allocated for a maximum of 8 flags
 	 * Flags directing saving/loading of a variable */
-	SLF_SAVE_NO      = 1 <<  8, ///< do not save with savegame, basically client-based
-	SLF_CONFIG_NO    = 1 <<  9, ///< do not save to config file
-	SLF_NETWORK_NO   = 1 << 10, ///< do not synchronize over network (but it is saved if SSF_SAVE_NO is not set)
-	/* 5 more possible flags */
+	SLF_NOT_IN_SAVE     = 1 <<  8, ///< do not save with savegame, basically client-based
+	SLF_NOT_IN_CONFIG   = 1 <<  9, ///< do not save to config file
+	SLF_NO_NETWORK_SYNC = 1 << 10, ///< do not synchronize over network (but it is saved if SLF_NOT_IN_SAVE is not set)
+	SLF_ALLOW_CONTROL   = 1 << 11, ///< allow control codes in the strings
+	SLF_ALLOW_NEWLINE   = 1 << 12, ///< allow new lines in the strings
+	/* 3 more possible flags */
 };
 
 typedef uint32 VarType;
@@ -330,7 +333,7 @@ typedef SaveLoad SaveLoadGlobVarList;
  * @param from   First savegame version that has the empty space.
  * @param to     Last savegame version that has the empty space.
  */
-#define SLE_CONDNULL(length, from, to) SLE_CONDARR(NullStruct, null, SLE_FILE_U8 | SLE_VAR_NULL | SLF_CONFIG_NO, length, from, to)
+#define SLE_CONDNULL(length, from, to) SLE_CONDARR(NullStruct, null, SLE_FILE_U8 | SLE_VAR_NULL | SLF_NOT_IN_CONFIG, length, from, to)
 
 /** Translate values ingame to different values in the savegame and vv. */
 #define SLE_WRITEBYTE(base, variable, value) SLE_GENERAL(SL_WRITEBYTE, base, variable, 0, 0, value, value)
@@ -440,7 +443,7 @@ typedef SaveLoad SaveLoadGlobVarList;
  * @param from   First savegame version that has the empty space.
  * @param to     Last savegame version that has the empty space.
  */
-#define SLEG_CONDNULL(length, from, to) {true, SL_ARR, SLE_FILE_U8 | SLE_VAR_NULL | SLF_CONFIG_NO, length, from, to, (void*)NULL}
+#define SLEG_CONDNULL(length, from, to) {true, SL_ARR, SLE_FILE_U8 | SLE_VAR_NULL | SLF_NOT_IN_CONFIG, length, from, to, (void*)NULL}
 
 /** End marker of global variables save or load. */
 #define SLEG_END() {true, SL_END, 0, 0, 0, 0, NULL}
@@ -513,7 +516,7 @@ static inline bool IsNumericType(VarType conv)
  */
 static inline void *GetVariableAddress(const void *object, const SaveLoad *sld)
 {
-	return (byte*)(sld->global ? NULL : object) + (ptrdiff_t)sld->address;
+	return const_cast<byte *>((const byte*)(sld->global ? NULL : object) + (ptrdiff_t)sld->address);
 }
 
 int64 ReadValue(const void *ptr, VarType conv);
